aboutsummaryrefslogtreecommitdiffstats
path: root/branch.h
diff options
context:
space:
mode:
Diffstat (limited to 'branch.h')
-rw-r--r--branch.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/branch.h b/branch.h
index 30c01aed73..ec2f35fda4 100644
--- a/branch.h
+++ b/branch.h
@@ -78,26 +78,26 @@ void create_branch(struct repository *r,
* those of create_branch() except for start_name, which is represented
* by two different parameters:
*
* - start_commitish is the commit-ish, in repository r, that determines
* which commits the branches will point to. The superproject branch
* will point to the commit of start_commitish and the submodule
* branches will point to the gitlink commit oids in start_commitish's
* tree.
*
* - tracking_name is the name of the ref, in repository r, that will be
* used to set up tracking information. This value is propagated to
* all submodules, which will evaluate the ref using their own ref
* stores. If NULL, this defaults to start_commitish.
*
* When this function is called on the superproject, start_commitish
* can be any user-provided ref and tracking_name can be NULL (similar
* to create_branches()). But when recursing through submodules,
* start_commitish is the plain gitlink commit oid. Since the oid cannot
* be used for tracking information, tracking_name is propagated and
* used for tracking instead.
*/
void create_branches_recursively(struct repository *r, const char *name,
- const char *start_commitish,
+ const char *start_committish,
const char *tracking_name, int force,
int reflog, int quiet, enum branch_track track,
int dry_run);
@@ -78,26 +78,26 @@ void create_branch(struct repository *r,
* by two different parameters:
*
- * - start_commitish is the commit-ish, in repository r, that determines
+ * - start_committish is the commit-ish, in repository r, that determines
* which commits the branches will point to. The superproject branch
@@ -78,26 +78,26 @@ void create_branch(struct repository *r,
* which commits the branches will point to. The superproject branch
- * will point to the commit of start_commitish and the submodule
- * branches will point to the gitlink commit oids in start_commitish's
+ * will point to the commit of start_committish and the submodule
+ * branches will point to the gitlink commit oids in start_committish's
* tree.
*
@@ -78,26 +78,26 @@ void create_branch(struct repository *r,
* used to set up tracking information. This value is propagated to
* all submodules, which will evaluate the ref using their own ref
- * stores. If NULL, this defaults to start_commitish.
+ * stores. If NULL, this defaults to start_committish.
*
@@ -78,26 +78,26 @@ void create_branch(struct repository *r,
*
- * When this function is called on the superproject, start_commitish
+ * When this function is called on the superproject, start_committish
* can be any user-provided ref and tracking_name can be NULL (similar
* to create_branches()). But when recursing through submodules,
@@ -78,26 +78,26 @@ void create_branch(struct repository *r,
* can be any user-provided ref and tracking_name can be NULL (similar
* to create_branches()). But when recursing through submodules,
- * start_commitish is the plain gitlink commit oid. Since the oid cannot
+ * start_committish is the plain gitlink commit oid. Since the oid cannot
* be used for tracking information, tracking_name is propagated and
* used for tracking instead.